<?php

/**
 * Fortune page element.
 *
 * $Id: index.php 594 2006-03-20 11:12:42Z stijn $
 * @package sws
 */

/**
 * Set options for the fortune box. Called by the framework.
 * @param array $options options for this box.
 * @access private
 */
function boxFortuneOptions($options)
{
	global $PAGE;

	$config = configPath();
	$PAGE["boxFortune"]["file"] = isset($options["file"]) ?
	    $options["file"] : swsroot() . "/doc/swshints";
	$PAGE["boxFortune"]["prepare"] = isset($options["prepare"]) ?
	    $options["prepare"] : false;
	$PAGE["boxFortune"]["short"] = isset($options["short"]) ?
	    $options["short"] : false;
	$PAGE["boxFortune"]["title"] = isset($options["title"]) ?
	    $options["title"] : "Fortune";
}

/**
 * Display a fortune box.
 *
 * Displays a box with a random quote.
 * As with all boxes, call addBox() from within the theme before using a box.
 */
function boxFortune()
{
	global $PAGE;

	$fortune = readFortune($PAGE["boxFortune"]["file"],
	    $PAGE["boxFortune"]["short"]);
	if ($fortune === false) {
		$fortune = "Sorry, fortune temporarily disabled.";
	}

	if ($PAGE["boxFortune"]["prepare"]) {
		$fortune = str_replace("\010", "^H", $fortune);
		$fortune = htmlentities($fortune);
		$fortune = "<p>" . $fortune . "</p>\n";
	}

	boxStart($PAGE["boxFortune"]["title"], "fortune");
	print $fortune;
	boxEnd();
}

/**
 * Read a fortune from a file.
 *
 * Returns a verbatim fortune string, or false if the file is unreadable.
 * Fortunes are formatted according to standard Unix fortune file
 * conventions, with messages separated by <literal>%</literal> starting
 * in column one on a single line (without whitespace at the end of the line).
 * Running strfile(8) on a Unix system is not necessary.
 * @param string $file the filename to read fortunes from
 * @param int $short the maximum number of characters that the returned fortune may have
 * @return string the fortune selected or false if an error occurred.
 */
function readFortune($file, $short = false)
{
	if (!is_readable($file)) {
		return false;
	}

	$fortunes = explode("%\n", file_get_contents($file));
	$fortune = $fortunes[rand(0, sizeof($fortunes) - 1)];
	while ($short && strlen($fortune) > $short) {
		$fortune = $fortunes[rand(0, sizeof($fortunes) - 1)];
	}
	unset($fortunes);

	return $fortune;
}

?>
