<?php

/**
 * Image gallery extension.
 *
 * $Id: index.php 594 2006-03-20 11:12:42Z stijn $
 * @package sws
 */

/**
 * Callback to set options for this extension.
 *
 * None needed at the moment.
 * @access private
 */
function extImagesOptions()
{
}

/**
 * User sort function callback for {@link showImages}
 * @param array $a image array to compare
 * @param array $b image array to compare
 * @return int 0 if $a equals $b, -1 if $a < $b and 1 if $a > $b
 * @access private
 */
function sortImage($a, $b)
{
	if ($a[0] == $b[0]) return 0;
	return ($a[0] > $b[0]) ? 1 : -1;
}

/**
 * Show images in a directory.
 *
 * Assumes a preview directory beneath the directory $dir, with name
 * 'preview', containing thumbnails for the images in the directory.
 * @param string $dir the directory, relative to the current page, with images
 * @param string $extragets extra options to specify in the GET URLs
 */
function showImages($dir, $extragets = "") {
	$realdir = dirname($_SERVER['SCRIPT_FILENAME']) . "/" . $dir . "/";

	if (is_file($realdir . "titles.txt")) {
		$titles = file($realdir . "titles.txt");
	} else {
		$titles = array();
	}

	if (isset($_REQUEST["showimage"])) {
		$showimage = $_REQUEST["showimage"];
		if (!is_file($realdir . sprintf("%03d", $showimage) . ".jpg")) {
			print "<p>No such image.\n";
			return;
		}
		$title = (isset($titles[$showimage - 1]) ?
				$titles[$showimage - 1] :
				sprintf("%03d", $showimage));
		print "<p>";
		print "<table border=\"0\" width=\"100%\">\n";
		print "<tr>\n";
		print "  <td align=\"center\" colspan=\"3\">\n";
		print "  <img src=\"" . $dir . "/" .
			sprintf("%03d", $showimage) . ".jpg\" " .
			"border=\"0\" alt=\"Image\"><br>\n";
		print "  " . $title . "\n";
		print "  </td>\n";
		print "</tr>\n";
		print "<tr>\n";
		print "  <td align=\"left\">\n";
		print "  <a href=\"" . me() . "?showimage=" .
			($showimage - 1) . $extragets . "\">Previous</a>\n";
		print "  </td>\n";
		print "  <td align=\"center\">\n";
		print "  <a href=\"" . me() . "?page=" .
			floor((($showimage - 1) / 20) + 1) . $extragets .
			"\">Back</a>\n";
		print "  </td>\n";
		print "  <td align=\"right\">\n";
		print "  <a href=\"" . me() . "?showimage=" .
			($showimage + 1) . $extragets . "\">Next</a>\n";
		print "  </td>\n";
		print "</tr>\n";
		print "</table>\n";
		return;
	}

	$page = (isset($_REQUEST["page"]) ?
			$_REQUEST["page"] - 1 : 0);

	$previewdir = $realdir . "preview/";
	$previewurl = $dir . "/preview/";

	if (!is_dir($previewdir)) {
		print "Error: preview directory (" . $previewdir . ") " .
			"does not exist.";
		return;
	}

	$i = 0;
	$entries = dir($realdir);
	while ($entry = $entries->read()) {
		if (!strstr($entry, ".jpg")) {
			continue;
		}

		$entry = substr($entry, 0, 3);

		$title = (isset($titles[$entry - 1]) ?
				$titles[$entry - 1] : $entry);
		$images[$i++] = array($entry, $title);
	}

	usort($images, "sortImage");

	if ($page < 0 || ($page * 20) > sizeof($images)) {
		print "<p>No such page.";
		return;
	}

	print "<table border=\"0\" width=\"100%\">\n";
	print "<tr>\n";
	print "<td align=\"center\">\n";
	print "<table border=\"0\">\n";
	print "<tr>\n";
	print "<td colspan=\"4\" align=\"right\">\n";
	print "Pages: ";
	for ($i = 1; ($i - 1) * 20 < sizeof($images); $i++) {
		if ($i - 1 != $page) {
			print "<a href=\"" . me() . "?page=" . $i .
				$extragets . "\">" . $i . "</a>";
		} else {
			print "<b>" . $i . "</b>";
		}
		if ($i * 20 < sizeof($images)) {
			print "|";
		}
	}
	print "\n";
	print "</td>\n";
	print "</tr>\n";
	print "<tr>\n";
	for ($i = $page * 20; $i < ($page + 1) * 20; $i++) {
		print "<td width=\"25%\" align=\"center\" valign=\"top\">\n";
		print "  <a href=\"" . me() . "?showimage=" .
			($images[$i][0] + 0) . $extragets . "\">" .
			"<img src=\"" . $previewurl . $images[$i][0] .
			"-small.jpg\" border=\"0\" alt=\"\">" .
			"<br>" . $images[$i][1] . "</a>\n";
		print "</td>\n";
		if (($i + 1) == sizeof($images)) {
			break;
		}
		if (($i + 1) % 4 == 0 && $i != (($page + 1) * 20) - 1) {
			print "</tr>\n";
			print "<tr>\n";
		}
	}
	print "</tr>\n";
	print "</table>\n";
	print "</td>\n";
	print "</tr>\n";
	print "</table>\n";
}

?>
