<?php

/**
 * Debugging functions for the framework.
 *
 * $Id: debug.php 594 2006-03-20 11:12:42Z stijn $
 * @package sws
 */

/**
 * Print a debug message.
 *
 * Checks whether PHP is running as an Apache module; if so, surrounds
 * $msg with HTML code.
 * @param string $msg the message to print
 */
function debug($msg)
{
	if (strpos(php_sapi_name(), "apache") === false) {
		print "DEBUG: " . $msg . "\n";
	} else {
		print "<pre>\nDEBUG: " . $msg . "\n</pre>\n";
	}
}

/**
 * Check whether a site wants debugging information.
 * @return bool true if the current site wants debugging information displayed
 */
function debugging_on()
{
	$config = configPath();
	if (isset($_SESSION["conf-$config"]['sws']['debug'])) {
		return ($_SESSION["conf-$config"]['sws']['debug'] ?
			true : false);
	}

	return false;
}

/**
 * Print out a pretty stack backtrace prefixed with a message.
 *
 * This function checks whether PHP is running as an Apache module, and
 * surrounds $msg and backtrace with HTML code if so.
 * @param string $msg the message to display.
 */
function err_backtrace($msg)
{
	$ap = (strpos(php_sapi_name(), "apache") === false ? 0 : 1);

	if ($ap) {
		print "</table><pre>";
	}
	print $msg . "\n";
	$bt = debug_backtrace();
	for ($i = 2; $i < sizeof($bt); $i++) {
		if (isset($bt[$i]['file']) && isset($bt[$i]['line'])) {
			print "From: " . $bt[$i]['file'] . ":" .
			    $bt[$i]['line'] . "\n";
		} else {
			print "From: [unknown code]\n";
		}
	}
	if ($ap) {
		print "</pre>\n";
	}
}

?>
