<?php

/**
 * Main include file for the framework. Manages the relationships between
 * the other include files, and defines the most important functions.
 *
 * $Id: main.php 616 2006-06-30 08:40:03Z stijn $
 * @package sws
 */

/**
 * The SWS version.
 */
define('SWSVERSION', '0.6.0');

/**
 * Return the path to the SWS root directory.
 * @return string the path to the SWS root directory
 */
function swsroot()
{
	$path = realpath(dirname(__FILE__) . "/../");
	return $path;
}

set_include_path(swsroot() . "/include");

require('time.php');
$PAGE['renderstart'] = getmicrotime();

require('database.php');
require('db.php');
require('db_mysql.php');
require('db_postgresql.php');
require('config.php');
require('striptags.php');
require('debug.php');
require('misc.php');
require('sitepath.php');
require('session.php');
require('state.php');
require('user.php');
require('login.php');
require('boxes.php');
require('themes.php');
require('extensions.php');

restore_include_path();

session_start();

setConfig();

// Make sure we display all warnings and errors when debugging is on
if (debugging_on()) {
	ini_set("display_errors", "1");
	error_reporting(E_ALL);
}

// Restore state if appropriate (we have a 'done' cookie and we can find
// a saved state)
if (isset($_COOKIE['swsdone']) && stateSaved($_COOKIE['swsdone'])) {
	restoreState($_COOKIE['swsdone']);
}

/**
 * Merge options for a directory with the default options for a site.
 * @param string $opfile the filename with complete path for .options
 * @param array $options the current page options
 * @return array the merged array of options
 * @access private
 */
function merge_options($opfile, $options)
{
	$config = parseConfig($opfile);
	return array_merge($config, $options);
}

/**
 * Output the pre-content section of the page.
 *
 * The heart of SWS, this function sets allmost all SWS specific functions
 * in motion. See the main documentation for an overview of what this does.
 * @param string $title the title of the current page
 * @param array $options the hash of options for this page
 */
function pre($title = "Untitled", $options = array() )
{
	global $PAGE;

	$opfile = dirname($_SERVER["SCRIPT_FILENAME"]) . "/.options";
	if (is_readable($opfile)) {
		$options = merge_options($opfile, $options);
	}

	// Do this as soon as possible while still allowing a page to
	// override this. DO NOT OVERRIDE THIS WITHOUT REALIZING THE
	// CONSEQUENCES OF USING USER SUPPLIED DATA! SEE striptags.php
	// FOR THE REASON THAT THIS IS TURNED ON BY DEFAULT!
	if (!isset($options['no_striptags'])) {
		striptags();
	}

	$PAGE['title'] = $title;
	$PAGE['options'] = $options;
	$PAGE['index'] = getIndex(me());
	$PAGE['topics'] = (isset($options['topics']) ?
			convertTopics($options['topics']) : getTopics(me()));
	$PAGE['backlink'] = getBacklink(me());

	// Make sure we haven't loadead a theme yet before loading it again
	if (!isset($PAGE['theme'])) {
		loadTheme(isset($options['theme']) ? $options['theme'] :
		    defaultTheme(me()));
	}

	if (isset($options['extensions']) && is_array($options['extensions'])) {
		foreach ($options['extensions'] as $ext) {
			addExtension($ext);
		}
	}

	if (!isset($options['inindex'])) {
		$options['inindex'] = 1;
	}

	if ((!isset($options['error']) || !$options['error']) &&
	    ($_SERVER["REQUEST_METHOD"] != "CONNECT")) {
		setURLTitle(me(), $PAGE['title'], $options['inindex']);
	}

	if (isset($options['restricted'])) {
		requireLogin($options['restricted']);
	}

	if (isset($options['usedb'])) {
		encryptProtocol();
		if (is_array($options['usedb'])) {
			foreach ($options['usedb'] as $dbname) {
				db_get_object($dbname);
			}
		} else {
			db_get_object($options['usedb']);
		}
	}

	if (isset($options['changepw'])) {
		changePassword();
	}

	preContent();
}

/**
 * Output the post-content section of the page.
 *
 * This is almost always a simple footer, as defined by the theme.
 */
function post()
{
	postContent();
}

?>
