<?php

/**
 * State functions.
 *
 * $Id: state.php 559 2005-11-21 15:15:55Z stijn $
 * @package sws
 */

/**
 * Checks for a saved state identified by a name.
 */
function stateSaved($name)
{
	return isset($_SESSION["savedpost-$name"]);
}

/**
 * Save the current page request state using an identifier.
 *
 * Saves the following variables in the current session:
 * - $_POST
 * - $_GET
 * - $_SERVER['QUERY_STRING']
 * In practice, this is enough to allow a user application to restore
 * to a previous state by using {@link restoreState}.
 *
 * This function does not currently nest, it will happily overwrite
 * the old saved state if called twice.
 */
function saveState($name)
{
	$_SESSION["savedpost-$name"] = serialize($_POST);
	$_SESSION["savedget-$name"] = serialize($_GET);
	$_SESSION["savedquery-$name"] = $_SERVER['QUERY_STRING'];
}

/**
 * Restore previously stored state.
 *
 * Restore the state stored in the session by {@link saveState}.
 * Specifically, it restores the following variables:
 * - $_POST
 * - $_GET
 * - $_SERVER['QUERY_STRING']
 * Using the restored state, the superglobal array l$_REQUEST is
 * reconstructed.
 */
function restoreState($name)
{
	$_POST = unserialize($_SESSION["savedpost-$name"]);
	unset($_SESSION["savedpost-$name"]);
	session_unregister("savedpost-$name");
	$_GET = unserialize($_SESSION["savedget-$name"]);
	unset($_SESSION["savedget-$name"]);
	session_unregister("savedget-$name");
	$_SERVER['QUERY_STRING'] = $_SESSION["savedquery-$name"];
	unset($_SESSION["savedquery-$name"]);
	session_unregister("savedquery-$name");

	//XXX: should use ini_get(variables_order) ?
	//     strange... returns GPCS but $_REQUEST does not contain $_SERVER
	$_REQUEST = array_merge($_GET, $_POST, $_COOKIE);
}

?>
