<?php

/**
 * Functions to manage the theme code.
 *
 * $Id: themes.php 492 2005-08-15 09:59:19Z stijn $
 * @package sws
 */

/**
 * Includes the default theme if no theme is loaded already.
 */
function needTheme()
{
	global $PAGE;

	if (!isset($PAGE['theme'])) {
		loadTheme(defaultTheme(me()));
	}
}

/**
 * Loads the indicated theme.
 * @param string $name the name of the wanted theme
 */
function loadTheme($name)
{
	global $PAGE;

	$PAGE['theme']['name'] = $name;
	setTheme();
}

/**
 * Determine the name of the default theme.
 * @return string the name of the default theme for this page.
 */
function defaultTheme($url)
{
	$config = configPath();
	return $_SESSION["conf-$config"]['sws']['defaulttheme'];
}

/**
 * Set the theme for this page.
 */
function setTheme()
{
	global $PAGE;

	$config = configPath();
	if (!isset($PAGE['theme']['name']) || 
	    !isset($_SESSION["theme-$config"]['name']) ||
	    $PAGE['theme']['name'] != $_SESSION["theme-$config"]['name']) {
		// Page uses another theme, find it
		$dirs = $_SESSION["conf-$config"]['sws']['themedirs'];
		$url = "";
		for ($i = 0; $i < sizeof($dirs); $i++) {
			$dir = $dirs[$i] . $PAGE['theme']['name'] . "/";
			if (file_exists($dir . "index.php")) {
				$url =
				    $_SESSION["conf-$config"]['sws']['themeurls'][$i] .
				    $PAGE['theme']['name'] . "/";
				break;
			}
		}

		// Error out if we didn't find it.
		if ($url == "") {
			print "<p>" . $PAGE['theme']['name'] . 
			    " - No such theme in theme include path " .
			    implode(":",
				$_SESSION["conf-$config"]['sws']['themedirs']) .
				"\n";
			exit;
		}

		$_SESSION["theme-$config"]['name'] = $PAGE['theme']['name'];
		$_SESSION["theme-$config"]['url'] = $url;
		$_SESSION["theme-$config"]['directory'] = $dir;
	}

	$PAGE['theme']['url'] = $_SESSION["theme-$config"]['url'];
	$PAGE['theme']['directory'] = $_SESSION["theme-$config"]['directory'];
	require($PAGE['theme']['directory'] . "index.php");
	setThemeOptions(isset($PAGE['options']) ? $PAGE['options'] : array());
}

?>
