<?php

/**
 * User data functions (including application session data).
 *
 * $Id: user.php 611 2006-06-29 10:43:58Z martijnw $
 * @package sws
 */

/**
 * Determines whether the specified application has data stored in the
 * application specific session variable.
 * @param string $app application identifier
 * @return bool true if the application uses session data, false if not
 */
function hasParams($app)
{
	$config = configPath();
	return isset($_SESSION["user-$config"]['app'][$app]);
}

/**
 * Returns application specific session data.
 *
 * This functions returns a reference to a hash object that can be used to
 * store application related data. All data stored will be preserved inbetween
 * page views, by use of the $_SESSION variable.
 *
 * Note that this function returns a reference; this means that you need to
 * reference-assign it in order to make use of it. I.e. the following code
 * works:
 *
 * <code>
 * $config =& getParams("app");
 * $config["foo"] = "bar";
 * </code>
 *
 * but the following code will not set the right value:
 *
 * <code>
 * $config = getParams("app");
 * $config["foo"] = "bar";
 * </code>
 *
 * Note the missing & in the assignment.
 *
 * Applications need to provide a disctinct application key to this function.
 * It is suggested that this key also contains the path to this application,
 * so as to allow multiple instances of the same SWS application to coexist on
 * the same host.
 * @param string $app the application key
 * @return array the application session data hash for this application
 */
function &getParams($app)
{
	$config = configPath();
	if (!hasParams($app)) {
		$_SESSION["user-$config"]['app'][$app] = array();
	}

	return $_SESSION["user-$config"]['app'][$app];
}

/**
 * Resets the application session data.
 * @param string $app the application key
 */
function resetParams($app)
{
	$config = configPath();
	if (hasParams($app)) {
		unset($_SESSION["user-$config"]['app'][$app]);
	}
}

/**
 * Return the id of the currently authenticated user.
 * @return int the id of the currently authenticated user, or -1 for guests
 */
function userId()
{
	$tkt = verifyTicket();
	return isset($tkt['id']) ? $tkt['id'] : -1;
}

/**
 * Return the login name of either the currently authenticated or the
 * specified user.
 * @param int $id the user to return the login name for (default: current user)
 * @return mixed the login name of the user or -1 if the userid was not found
 */
function userLogin($id = -1)
{
	if ($id == -1) {
		$tkt = verifyTicket();
		return isset($tkt['login']) ? $tkt['login'] : -1;
	}

	$db = db_get_object("sws");
	$res = $db->query("SELECT login FROM users WHERE id = " . (0 + $id));
	if (!$res) {
		return -1;
	}

	if ($res->num_rows() == 0) {
		return -1;
	}

	$login = $res->fetch_array();
	return $login[0];
}

/**
 * Return the email address of either the currently authenticated or the
 * specified user.
 * @param int $id the user to return the email address for (default: current user)
 * @return string the email address of the user
 */
function userEmail($id = -1)
{
	if ($id == -1) {
		$tkt = verifyTicket();
		$id = isset($tkt['id']) ? $tkt['id'] : -1 ;	
	}

	$db = db_get_object("sws");
	$res = $db->query("SELECT email FROM users WHERE id = " . (0 + $id));
	if (!$res) {
		return -1;
	}

	if ($res->num_rows() == 0) {
		return -1;
	}

	$email = $res->fetch_array();
	return $email[0];
}

?>
