#
# $Id: DB.pm 526 2005-09-05 15:14:20Z stijn $
#
# SWS tool database functions.
#

package SWS::DB;

use strict;
use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

require Exporter;

@ISA = qw(Exporter);
@EXPORT = qw(
	db_params db_connect db_type
);
$VERSION = '0.5';

use DBI;

use SWS::Cfg;
use SWS::Root;
use SWS::Error;

sub db_params
{
	my ($arg) = @_;

	die "need db parameter\n" if not defined($arg);

	my $swsroot = swsroot();

	my ($site, $db) = split(/:/, $arg);
	if (!defined($db)) {
		$db = $site;
		$site = undef;
	}

	my $hostname = `hostname`;
	chomp($hostname);
	my $id = getpwuid($<);
	chomp($id);

	my $configfile = "$swsroot/etc/db/$db";
	if (defined($site) && (-r "$site/.sws/db/$db")) {
		$configfile = "$site/.sws/db/$db";
	}
	die("$db config file not found or not readable in path " .
	    (defined($site) ? "$site:" : "") . "$swsroot/etc/db\n")
	    unless (-r "$configfile");

	my %cfg = parse_config($configfile);

	my %dbparam;
	$dbparam{'type'} = $cfg{"type"};
	$dbparam{'name'} = ($ENV{'DBNAME'} ? $ENV{'DBNAME'} : $cfg{"name"});
	$dbparam{'name'} = $hostname if (!defined($dbparam{'name'}));
	$dbparam{'host'} = ($ENV{'DBHOST'} ? $ENV{'DBHOST'} : $cfg{"host"});
	$dbparam{'host'} = "localhost" if (!defined($dbparam{'host'}));
	$dbparam{'user'} = ($ENV{'DBUSER'} ? $ENV{'DBUSER'} : $cfg{"user"});
	$dbparam{'user'} = $id if (!defined($dbparam{'user'}));
	$dbparam{'password'} = ($ENV{'DBPASSWORD'} ? $ENV{'DBPASSWORD'} :
	    $cfg{"password"});
	$dbparam{'password'} = "" if (!defined($dbparam{'password'}));

	return %dbparam;
}

sub db_connect
{
	my ($dbname) = @_;

	my %dbparam = db_params($dbname);

	my $dbh;
	if ($dbparam{'type'} eq "mysql") {
		$dbh = DBI->connect("DBI:mysql:database=" .
		    $dbparam{'name'} . ":host=" . $dbparam{'host'},
		    $dbparam{'user'}, $dbparam{'password'},
		    { RaiseError => 0, PrintError => 0 })
			|| die("could not connect to database $dbname\n");
	} elsif ($dbparam{'type'} eq "postgresql") {
		$dbh = DBI->connect("DBI:Pg:dbname=" . $dbparam{'name'} .
		    ($dbparam{'host'} ne "localhost" ?
			";host=" . $dbparam{'host'} : ""),
		    $dbparam{'user'}, $dbparam{'password'},
		    { RaiseError => 0, PrintError => 0 })
			|| die("could not connect to database $dbname\n");
	} else {
		die("unknown database type $dbparam{'type'}\n");
	}

	return $dbh;
}

sub db_type
{
	my ($dbh) = @_;

	my $type = lc($dbh->get_info(17));
	#XXX of course the DBI::Pg driver doesn't cooperate :(
	#    let's hope other drivers do not return an empty string
	if ($type eq "") {
		$type = "postgresql";
	}
	return $type;
}

1;
