#!/bin/sh
#
# $Id: apache2sites.sh 443 2005-03-31 13:35:45Z stijn $
#

# PROVIDE: apache2sites
# REQUIRE: apache2
# KEYWORD: FreeBSD shutdown

#
# Add the following lines to /etc/rc.conf
# apache2sites_enable (bool): Set to "NO" by default.
#                             Set it to "YES" to enable separate subsites
#
. /etc/rc.subr

name="apache2sites"
rcvar=`set_rcvar`

start_cmd="${name}_start"
stop_cmd="${name}_stop"
reload_cmd="${name}_reload"
status_cmd="${name}_status"
required_dirs=/usr/local/etc/apache2/sites

[ -z "$apache2sites_enable" ] && \
		apache2sites_enable="NO"
[ -z "$apache2sites_dir" ]    && \
		apache2sites_dir="/usr/local/etc/apache2/sites"
[ -z "$apache2sites_sites" ]  && \
		apache2sites_sites=`ls ${apache2sites_dir} | grep -v conf`

load_rc_config $name

apache2sites_start()
{
	echo "Starting apache2 subsites:"

	for site in ${apache2sites_sites}; do
		pid=$(check_pidfile /var/run/httpd-${site}.pid \
			/usr/local/sbin/httpd)
		if [ ! -z "$pid" ]; then
			echo "  ${site} already running, skipped"
		else
			/usr/bin/env -i PHPRC=${apache2sites_dir}/${site} \
			    /usr/local/sbin/httpd \
				-f ${apache2sites_dir}/${site}/httpd.conf \
				-k start
			echo "  ${site}"
		fi
	done
}

apache2sites_stop()
{
	echo "Stopping apache2 subsites:"

	for site in ${apache2sites_sites}; do
		pid=$(check_pidfile /var/run/httpd-${site}.pid \
			/usr/local/sbin/httpd)
		if [ -z "$pid" ]; then
			echo "  ${site} not running?"
		else
			/usr/bin/env -i PHPRC=${apache2sites_dir}/${site} \
			    /usr/local/sbin/httpd \
				-f ${apache2sites_dir}/${site}/httpd.conf \
				-k stop
			echo "  ${site}"
		fi
	done
}

apache2sites_reload()
{
	echo "Reloading apache2 subsite config files:"

	for site in ${apache2sites_sites}; do
		pid=$(check_pidfile /var/run/httpd-${site}.pid \
			/usr/local/sbin/httpd)
		if [ -z "$pid" ]; then
			echo "  ${site} not running?"
		else
			/usr/bin/env -i PHPRC=${apache2sites_dir}/${site} \
			    /usr/local/sbin/httpd \
				-f ${apache2sites_dir}/${site}/httpd.conf \
				-k graceful
			echo "  ${site}"
		fi
	done
}

apache2sites_status()
{
	echo "Status of apache2 subsites:"

	for site in ${apache2sites_sites}; do
		pid=$(check_pidfile /var/run/httpd-${site}.pid \
			/usr/local/sbin/httpd)
		if [ -z "$pid" ]; then
			echo "  ${site} is not running."
		else
			echo "  ${site} is running as pid ${pid}."
		fi
	done
}

extra_commands="reload status"
run_rc_command "$1"
